@@ -7,8 +7,8 @@ from fabric.api import *
 from fabric.colors import *
 from fabric.contrib.console import confirm
 from ground_soil.fabric import eval_kwargs, virtual_env
-from ground_soil.filesystem import temporary_directory, edit_file
-from beanstalk import IDENTIFIER
+from ground_soil.filesystem import temporary_directory, render_file
+from beanstalk import IDENTIFIER, BEANSTALK_ROOT_PATH
 from beanstalk.decorators import beanstalk_role
 from beanstalk.tasks.utils import load_role_settings as load_beanstalk_settings, set_verbose_level
 from beanstalk.titles import tool_title, section_title
@@ -102,15 +102,21 @@ def setup(settings_path=None, **settings_patches):
             with lcd(uwsgi_src_folder):
                 # Create build configuration
                 local('mkdir -p /usr/local/lib/uwsgi')
-                local('echo "[uwsgi]" >> buildconf/beanstalk.ini')
-                local('echo "main_plugin = python" >> buildconf/beanstalk.ini')
-                local('echo "inherit = base" >> buildconf/beanstalk.ini')
-                local('echo "plugin_dir = /usr/local/lib/uwsgi" >> buildconf/beanstalk.ini')
+                config = ConfigParser.ConfigParser()
+                config.add_section('uwsgi')
+                config.set('uwsgi', 'main_plugin', 'python')
+                config.set('uwsgi', 'inherit', 'base')
+                config.set('uwsgi', 'plugin_dir', '/usr/local/lib/uwsgi')
+                with open(os.path.join(tmp_directory, uwsgi_src_folder, 'buildconf/beanstalk.ini'), 'w') as f:
+                    config.write(f)
                 # Build and install
                 local('python uwsgiconfig.py --build beanstalk')
                 local('cp uwsgi /usr/local/bin/uwsgi')
                 if not os.path.exists('/usr/bin/uwsgi'):
                     local('ln -s /usr/local/bin/uwsgi /usr/bin/uwsgi')
+                local('mkdir -p /var/run/beanstalk')
+                local('cp %s /etc/init.d/beanstalk' % os.path.join(BEANSTALK_ROOT_PATH, 'static/beanstalk_init.sh'))
+                local('chmod +x /etc/init.d/beanstalk')
                 # mod_uwsgi
                 local('apxs -i -c apache2/mod_uwsgi.c')
                 local('echo "LoadModule uwsgi_module modules/mod_uwsgi.so" > /etc/httpd/conf.d/uwsgi.conf')
@@ -127,7 +133,7 @@ def setup(settings_path=None, **settings_patches):
         local('passwd beanstalk')
         # Setup git
         local('su -c "git config --global user.name \'beanstalk\'" - beanstalk')
-        local('su -c "git config --global user.email beanstalk@beanstalk-stack.com" - beanstalk')
+        local('su -c "git config --global user.email %s" - beanstalk' % beanstalk_settings['BEANSTALK_EMAIL'])
         # Setup .ssh
         local('mkdir -p ~beanstalk/.ssh')
         local('chmod 700 ~beanstalk/.ssh')
@@ -147,23 +153,27 @@ def setup(settings_path=None, **settings_patches):
     # Apache command
     print section_title('Create apache-reload command')
     httpd_cmd_path = '/usr/sbin/httpd_reload'
-    with open(httpd_cmd_path, 'w') as f:
-        f.write('#!/bin/sh\n')
-        f.write('service httpd reload')
+    httpd_cmd_source = os.path.join(BEANSTALK_ROOT_PATH, 'static/httpd_reload.sh')
+    local('/bin/cp -f %s %s' % (httpd_cmd_source, httpd_cmd_path))
     local('chmod +x %s' % httpd_cmd_path)
+
     # Give beanstalk permission
+    print section_title('Give beanstalk permission for apache-reload command')
     sudoer_file = '/etc/sudoers.d/beanstalk_reload_httpd'
-    with open(sudoer_file, 'w') as f:
-        f.write('beanstalk ALL=(root) NOPASSWD: %s' % httpd_cmd_path)
+    local('echo "beanstalk ALL=(root) NOPASSWD: %s" > %s' % (httpd_cmd_path, sudoer_file))
     local('chmod 440 %s' % sudoer_file)
 
     # Make beanstalk access ssh
     local('sed -i.bak -e "/^AllowGroups wheel$/cAllowGroups wheel beanstalk" /etc/ssh/sshd_config')
 
     # Apache conf
+    beanstalk_apache_conf_template = os.path.join(BEANSTALK_ROOT_PATH, 'static/beanstalk_apache.conf')
+    beanstalk_apache_conf = render_file(
+        beanstalk_apache_conf_template, beanstalk_settings, BEANSTALK_APP_APACHE_CONF=apache_conf_path())
+    with open('/etc/httpd/conf.d/beanstalk.conf', 'w') as f:
+        f.read(beanstalk_apache_conf)
     local('echo "# Beanstalk Apache conf" > %s' % apache_conf_path())
     local('chown beanstalk:beanstalk %s' % apache_conf_path())
-    local('echo "Include %s" > /etc/httpd/conf.d/beanstalk.conf' % apache_conf_path())
 
     local('chown -R beanstalk:beanstalk %s' % beanstalk_stack_base)
     local('/etc/init.d/sshd restart')
@@ -459,7 +469,7 @@ def list_apps(settings_path=None, **settings_patches):
 @task
 @beanstalk_role('server')
 def commit_app(project_name, settings_path=None, **settings_patches):
-    """Get list of apps
+    """Commit app
     """
     settings_patches = eval_kwargs(settings_patches)
     load_beanstalk_settings(local_settings_path=settings_path, **settings_patches)
